"use strict";

var _interopRequireDefault = require("reshow-runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.sessionStorage = exports.localStorage = exports.Storage = void 0;
var _getObjectValue = _interopRequireDefault(require("get-object-value"));
var _winDoc = require("win-doc");
var _reshowConstant = require("reshow-constant");
var _Storage = _interopRequireDefault(require("./Storage.js"));
exports.Storage = _Storage["default"];
// @ts-check

var notSupport = {};
var getStorage =
/**
 * @param {string} storageType
 * @returns {Function}
 */
function getStorage(storageType) {
  return (
    /**
     * @param {string} key
     * @returns {Function}
     */
    function (key) {
      return (
        /**
         * @param {any} value
         * @returns {any}
         */
        function (value) {
          var oWin = (0, _winDoc.win)();
          if (!oWin || notSupport[storageType]) {
            return;
          }
          var store = (0, _getObjectValue["default"])(oWin, [storageType]);
          if (_reshowConstant.UNDEFINED === typeof store) {
            console.warn("Not support. [" + storageType + "]");
            notSupport[storageType] = true;
            return;
          }
          if (_reshowConstant.UNDEFINED === typeof value) {
            return store.getItem(key);
          } else {
            try {
              if (null == value) {
                return store.removeItem(key);
              }
              return store.setItem(key, value);
            } catch (err) {
              store.clear();
              return store.setItem(key, value);
            }
          }
        }
      );
    }
  );
};
var localStorage = exports.localStorage = getStorage("localStorage");
var sessionStorage = exports.sessionStorage = getStorage("sessionStorage");