// @ts-check
import get from "get-object-value";
import { win } from "win-doc";
import { UNDEFINED } from "reshow-constant";
var notSupport = {};
var getStorage =
/**
 * @param {string} storageType
 * @returns {Function}
 */
function getStorage(storageType) {
  return (
    /**
     * @param {string} key
     * @returns {Function}
     */
    function (key) {
      return (
        /**
         * @param {any} value
         * @returns {any}
         */
        function (value) {
          var oWin = win();
          if (!oWin || notSupport[storageType]) {
            return;
          }
          var store = get(oWin, [storageType]);
          if (UNDEFINED === typeof store) {
            console.warn("Not support. [" + storageType + "]");
            notSupport[storageType] = true;
            return;
          }
          if (UNDEFINED === typeof value) {
            return store.getItem(key);
          } else {
            try {
              if (null == value) {
                return store.removeItem(key);
              }
              return store.setItem(key, value);
            } catch (err) {
              store.clear();
              return store.setItem(key, value);
            }
          }
        }
      );
    }
  );
};
var localStorage = getStorage("localStorage");
var sessionStorage = getStorage("sessionStorage");
export { localStorage, sessionStorage };
export { default as Storage } from "./Storage.mjs";